/***************************************************************************
    wavchan.cxx

    Copyright (c) 2002-2003  Vladimir Toncar

    The contents of this file are subject to the Mozilla Public License
    Version 1.1 (the "License"); you may not use this file except in
    compliance with the License. You may obtain a copy of the License at
    http://www.mozilla.org/MPL/

    Software distributed under the License is distributed on an "AS IS"
    basis, WITHOUT WARRANTY OF ANY KIND, either express or implied.
    See the License for the specific language governing rights and
    limitations under the License.

    The Original Code is oh323tut.

    The Initial Developer of the Original Code is Vladimir Toncar.
    All Rights Reserved.

    Contributor(s): ______________________________________.

 ***************************************************************************/

#include "wavchan.h"


// ***********************************************************************

WavChannel::WavChannel(const PString & aFileName, H323Connection & _connection): 
	myConnection(_connection), 
	wavFile(aFileName, PFile::ReadOnly) 
{
	if (!wavFile.IsOpen()) 
	{
		PError << "Failed to open WAV file " << aFileName << endl;
      		myConnection.ClearCall();
		return;
	} 
	if (wavFile.GetFormat() != PWAVFile::fmt_PCM 
		|| wavFile.GetChannels() != 1
		|| wavFile.GetSampleRate() != 8000
		|| wavFile.GetSampleSize() != 16)
	{
		PError << "WAV file " << aFileName 
		       << " has wrong format." << endl;
		wavFile.Close();
		myConnection.ClearCall();
		return;
	} 
	
	PTRACE(1, "Created WAV channel for file " << aFileName);
	
} 


// ***********************************************************************

WavChannel::~WavChannel() 
{
	PTRACE(1, "Deleting WAV channel for file " << wavFile.GetName());
} 


// ***********************************************************************

BOOL WavChannel::Close() 
{
	PTRACE(1, "Close WAV file " << wavFile.GetName());
	return wavFile.Close();
} 


// ***********************************************************************

BOOL WavChannel::IsOpen() const 
{
	PTRACE(1, "WavChannnel::IsOpen(): " << wavFile.IsOpen());
	return wavFile.IsOpen();
} 


// ***********************************************************************

BOOL WavChannel::Write(const void * /*buf*/, PINDEX len) 
{
	PTRACE(2, "WavChannel::Write():" << len);
	lastWriteCount = len; 
	writeDelay.Delay(len / 16); 

	return true;
} 


// ***********************************************************************

BOOL WavChannel::Read(void *buf, PINDEX len) 
{
	if (!wavFile.Read(buf, len))  {
		PTRACE(2, "WavChannel::read of " << len << " bytes failed, return false");
		myConnection.ClearCall(); 
		return false;
	}
		
	lastReadCount = wavFile.GetLastReadCount(); 
	readDelay.Delay(lastReadCount / 16); 
	
	
	return lastReadCount == len; 
} 


// ***********************************************************************

